jacinle.utils.numeric
=====================

.. automodule:: jacinle.utils.numeric

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      divup
      mean
      prod
      rms
      safe_sum
      std
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: divup

.. autofunction:: mean

.. autofunction:: prod

.. autofunction:: rms

.. autofunction:: safe_sum

.. autofunction:: std


